const bcrypt = require('bcrypt');
const db = require('../config/db'); // เชื่อมต่อฐานข้อมูล

// ฟังก์ชันการลงทะเบียนผู้ใช้
exports.registerUser = async (req, res) => {
  const { username, password } = req.body;

  try {
    // เข้ารหัสรหัสผ่านก่อนที่จะบันทึก
    const hashedPassword = await bcrypt.hash(password, 10);

    // บันทึกผู้ใช้ใหม่ในฐานข้อมูล
    await db.execute('INSERT INTO users (username, password) VALUES (?, ?)', [username, hashedPassword]);

    res.status(201).send('User registered successfully');
  } catch (err) {
    console.error(err);
    res.status(500).send('Error registering user');
  }
};
// ฟังก์ชันการเข้าสู่ระบบ
exports.loginUser = async (req, res) => {
    const { username, password } = req.body;
  
    try {
      // ค้นหาผู้ใช้จากฐานข้อมูล
      const [rows] = await db.execute('SELECT * FROM users WHERE username = ?', [username]);
  
      if (rows.length === 0) {
        return res.status(400).send('Invalid username or password');
      }
  
      const user = rows[0];
  
      // ตรวจสอบรหัสผ่านที่ผู้ใช้กรอกกับรหัสผ่านที่เก็บในฐานข้อมูล
      const match = await bcrypt.compare(password, user.password);
  
      if (!match) {
        return res.status(400).send('Invalid username or password');
      }
  
      // หากการเข้าสู่ระบบสำเร็จ เก็บข้อมูลผู้ใช้ใน session
      req.session.user = user; // ใช้ session เพื่อเก็บข้อมูลผู้ใช้
      res.redirect('/product'); // หรือ redirect ไปยังหน้าอื่นๆ ที่ต้องการ
    } catch (err) {
      console.error(err);
      res.status(500).send('Error logging in');
    }
  };

