const db = require('../config/db');  // เชื่อมต่อกับฐานข้อมูล

// ฟังก์ชันบันทึกแบรนด์ใหม่
exports.createBrand = (req, res) => {
  const { name } = req.body;

  // ตรวจสอบข้อมูล
  if (!name) {
    return res.status(400).send('Brand name is required');
  }

  // คำสั่ง SQL สำหรับเพิ่มข้อมูลแบรนด์
  const query = 'INSERT INTO brands (name) VALUES (?)';

  // ใช้ mysql2 เพื่อบันทึกข้อมูล
  db.execute(query, [name])
    .then(([results, fields]) => {
      res.redirect('/brand-list');  // ไปที่หน้ารายการแบรนด์
    })
    .catch((err) => {
      console.error(err);
      res.status(500).send('Error creating brand');
    });
};
// ฟังก์ชันแสดงฟอร์มการสร้างแบรนด์
exports.createBrandForm = (req, res) => {
    res.render('create-brand', {
      title: 'Create Brand'
    });
  };
  

  

// ฟังก์ชันแสดงรายชื่อแบรนด์
exports.getBrandList = (req, res) => {
  const query = 'SELECT * FROM brands';

  db.execute(query)
    .then(([rows, fields]) => {
      res.render('brand-list', {
        title: 'Brand List',
        brands: rows,
      });
    })
    .catch((err) => {
      console.error(err);
      res.status(500).send('Error retrieving brand list');
    });
};
// ฟังก์ชันแสดงฟอร์มการแก้ไขแบรนด์
exports.editBrandForm = (req, res) => {
    const brandId = req.params.id;
  
    // คำสั่ง SQL เพื่อดึงข้อมูลแบรนด์
    const query = 'SELECT * FROM brands WHERE id = ?';
  
    db.execute(query, [brandId])
      .then(([rows, fields]) => {
        if (rows.length === 0) {
          return res.status(404).send('Brand not found');
        }
        res.render('edit-brand', {
          title: 'Edit Brand',
          brand: rows[0],
        });
      })
      .catch((err) => {
        console.error(err);
        res.status(500).send('Error retrieving brand');
      });
  };
  // ฟังก์ชันอัปเดตข้อมูลแบรนด์
exports.updateBrand = (req, res) => {
    const { name } = req.body;
    const brandId = req.params.id;
  
    // คำสั่ง SQL สำหรับอัปเดตแบรนด์
    const query = 'UPDATE brands SET name = ? WHERE id = ?';
  
    db.execute(query, [name, brandId])
      .then(([results, fields]) => {
        res.redirect('/brand-list');  // ไปที่หน้ารายการแบรนด์
      })
      .catch((err) => {
        console.error(err);
        res.status(500).send('Error updating brand');
      });
  };
  
  // ฟังก์ชันลบแบรนด์
exports.deleteBrand = (req, res) => {
    const brandId = req.params.id;
  
    // คำสั่ง SQL สำหรับลบข้อมูลแบรนด์
    const query = 'DELETE FROM brands WHERE id = ?';
  
    db.execute(query, [brandId])
      .then(([results, fields]) => {
        res.redirect('/brand-list');  // ไปที่หน้ารายการแบรนด์
      })
      .catch((err) => {
        console.error(err);
        res.status(500).send('Error deleting brand');
      });
  };
  