const productModel = require('../models/product');
const db = require('../config/db');
// ฟังก์ชันการแสดงฟอร์มการสร้างสินค้า
// ฟังก์ชันการแสดงฟอร์มการสร้างสินค้า
// ฟังก์ชันการแสดงฟอร์มการสร้างสินค้า
exports.createProductForm = async (req, res) => {
  try {
    // ดึงข้อมูลหมวดหมู่, แบรนด์, และผู้จัดจำหน่าย
    const [categories] = await db.execute('SELECT * FROM categories');
    const [brands] = await db.execute('SELECT * FROM brands');
    const [suppliers] = await db.execute('SELECT * FROM suppliers');

    // ส่งข้อมูลไปยังหน้า create-product.ejs
    res.render('create-product', {
      categories,  // ส่งข้อมูลหมวดหมู่
      brands,      // ส่งข้อมูลแบรนด์
      suppliers    // ส่งข้อมูลผู้จัดจำหน่าย
    });
  } catch (err) {
    console.error(err);
    res.status(500).send('Error fetching data');
  }
};
// สร้างสินค้าใหม่
// ฟังก์ชันการสร้างสินค้า
// ฟังก์ชันการสร้างสินค้าใหม่พร้อมการตรวจสอบข้อมูล
// ฟังก์ชันสำหรับการสร้างสินค้าใหม่
exports.createProduct = async (req, res) => {
  const { name, quantity, categoryId, supplierId, brandId } = req.body;  // รับข้อมูลจากฟอร์ม

  try {
    // เพิ่มสินค้าลงในฐานข้อมูล
    await db.execute(
      'INSERT INTO products (name, quantity, category_id, supplier_id, brand_id) VALUES (?, ?, ?, ?, ?)',
      [name, quantity, categoryId, supplierId, brandId]
    );

    // หลังจากสร้างสินค้าเสร็จ, redirect ไปที่หน้ารายการสินค้า
    res.redirect('/product');
  } catch (err) {
    console.error(err);
    res.status(500).send('Error creating product');
  }
};


// แสดงข้อมูลสินค้าทั้งหมด
exports.getProducts = async (req, res) => {
  try {
    const [rows] = await productModel.getProducts();
    res.render('index', { products: rows });
  } catch (err) {
    console.error(err);
    res.status(500).send('Error fetching products');
  }
};

// ฟังก์ชันการอัปเดตข้อมูลสินค้า (ชื่อ, หมวดหมู่, แบรนด์)
exports.updateProduct = async (req, res) => {
  const { id, name, quantity, categoryId, supplierId, brandId } = req.body; // รับข้อมูลจากฟอร์ม

  try {
    // อัปเดตข้อมูลสินค้าทั้งหมด
    await db.execute(
      'UPDATE products SET name = ?, quantity = ?, category_id = ?, supplier_id = ?, brand_id = ? WHERE id = ?',
      [name, quantity, categoryId, supplierId, brandId, id]
    );

    // หลังจากอัปเดตสินค้าเสร็จ, redirect ไปที่หน้ารายการสินค้า
    res.redirect('/product');
  } catch (err) {
    console.error(err);
    res.status(500).send('Error updating product');
  }
};


// ลบข้อมูลสินค้า
exports.deleteProduct = async (req, res) => {
  const { id } = req.params;
  try {
    await productModel.deleteProduct(id);
    res.redirect('/product');
  } catch (err) {
    console.error(err);
    res.status(500).send('Error deleting product');
  }
};

// ฟังก์ชันการแสดงสินค้าพร้อมการกรองและการเรียงลำดับ
// ฟังก์ชันการแสดงสินค้าพร้อมการกรองและการเรียงลำดับ
exports.searchProduct = async (req, res) => {
  const searchTerm = req.query.search || ''; // รับคำค้นหาจาก query parameter
  const categoryFilter = req.query.category || ''; // รับหมวดหมู่สินค้าจาก query parameter
  const brandFilter = req.query.brand || ''; // รับแบรนด์สินค้าจาก query parameter
  const sort = req.query.sort || 'id ASC'; // เรียงลำดับตาม ID เป็นค่าเริ่มต้น

  try {
    let query = 'SELECT products.id, products.name, products.quantity, categories.name AS category, brands.name AS brand, suppliers.name AS supplier FROM products ';
    query += 'JOIN categories ON products.category_id = categories.id ';
    query += 'JOIN brands ON products.brand_id = brands.id ';
    query += 'JOIN suppliers ON products.supplier_id = suppliers.id WHERE products.name LIKE ?';

    // ตัวแปรที่ใช้ในการส่งค่าให้คำสั่ง SQL
    const params = [`%${searchTerm}%`];

    // เพิ่มเงื่อนไขการกรองหมวดหมู่สินค้า
    if (categoryFilter) {
      query += ' AND categories.id = ?';
      params.push(categoryFilter);
    }

    // เพิ่มเงื่อนไขการกรองแบรนด์
    if (brandFilter) {
      query += ' AND brands.id = ?';
      params.push(brandFilter);
    }

    // เพิ่มการเรียงลำดับ
    query += ` ORDER BY ${sort}`;

    // ดึงข้อมูลสินค้าจากฐานข้อมูล
    const [rows] = await db.execute(query, params);

    // ดึงข้อมูลหมวดหมู่สินค้า, แบรนด์, ผู้จัดจำหน่าย
    const [categories] = await db.execute('SELECT * FROM categories');
    const [brands] = await db.execute('SELECT * FROM brands');
    const [suppliers] = await db.execute('SELECT * FROM suppliers');

    res.render('index', {
      products: rows,      // ส่งข้อมูลสินค้าที่ดึงมาจากฐานข้อมูล
      categories,          // ส่งข้อมูลหมวดหมู่สินค้า
      brands,              // ส่งข้อมูลแบรนด์
      suppliers,           // ส่งข้อมูลผู้จัดจำหน่าย
      searchTerm,
      categoryFilter,
      brandFilter,
      sort
    });
  } catch (err) {
    console.error(err);
    res.status(500).send('Error fetching products');
  }
};
// แสดงฟอร์มแก้ไขสินค้า


// ฟังก์ชันการแสดงฟอร์มการแก้ไขสินค้า
exports.editProductForm = async (req, res) => {
  const { id } = req.params;
  try {
    // ดึงข้อมูลสินค้าจากฐานข้อมูล
    const [product] = await db.execute('SELECT * FROM products WHERE id = ?', [id]);
    
    // ดึงข้อมูลหมวดหมู่สินค้า
    const [categories] = await db.execute('SELECT * FROM categories');
    
    // ดึงข้อมูลผู้จัดจำหน่าย (suppliers)
    const [suppliers] = await db.execute('SELECT * FROM suppliers');
    
    // ดึงข้อมูลแบรนด์ (brands)
    const [brands] = await db.execute('SELECT * FROM brands');

    // ส่งข้อมูลไปยัง view (edit.ejs)
    res.render('edit', { 
      product: product[0],   // ข้อมูลสินค้าที่ต้องการแก้ไข
      categories: categories, // ข้อมูลหมวดหมู่สินค้า
      suppliers: suppliers,  // ข้อมูลผู้จัดจำหน่าย
      brands: brands         // ข้อมูลแบรนด์
    });
  } catch (err) {
    console.error(err);
    res.status(500).send('Error fetching product or related data');
  }
};

  
  // ฟังก์ชันการอัปเดตสินค้า
exports.updateProductQuantity = async (req, res) => {
  const { id, quantity } = req.body;  // รับ id และ quantity จากฟอร์ม

  try {
    // อัปเดตเฉพาะจำนวนสินค้าที่ได้รับจากฟอร์ม
    await db.execute('UPDATE products SET quantity = ? WHERE id = ?', [quantity, id]);

    // หลังจากอัปเดตเสร็จ, redirect ไปที่หน้ารายการสินค้า
    res.redirect('/product');
  } catch (err) {
    console.error(err);
    res.status(500).send('Error updating product quantity');
  }
};
  
// ฟังก์ชันการลบหมวดหมู่
exports.deleteCategory = async (req, res) => {
  const { id } = req.params;

  try {
    // ตรวจสอบว่าไม่มีสินค้าติดต่อกับหมวดหมู่นี้
    const [checkProducts] = await db.execute('SELECT * FROM products WHERE category_id = ?', [id]);

    if (checkProducts.length > 0) {
      return res.status(400).send('Cannot delete category because there are products associated with it');
    }

    // ลบหมวดหมู่
    await db.execute('DELETE FROM categories WHERE id = ?', [id]);

    // Redirect ไปที่หน้าแสดงหมวดหมู่
    res.redirect('/product');
  } catch (err) {
    console.error(err);
    res.status(500).send('Error deleting category');
  }
};


