const express = require('express');
const router = express.Router();
const authController = require('../controllers/authController');
const productController = require('../controllers/productController');
const db = require('../config/db');
// เส้นทางสำหรับหน้า register
router.get('/register', (req, res) => {
    res.render('register');  // แสดงฟอร์มการสมัครสมาชิก
  });
  
  // เส้นทางการสมัครสมาชิก (POST)
  router.post('/register', authController.registerUser);
  
  // เส้นทางสำหรับหน้า login
  router.get('/', (req, res) => {
    res.render('login');  // แสดงฟอร์มการเข้าสู่ระบบ
  });

  // เส้นทางการแสดงฟอร์มการสร้างสินค้า
router.get('/create-product', productController.createProductForm);

// เส้นทางการสร้างสินค้า
router.post('/create-product', productController.createProduct);
  // เส้นทางการเข้าสู่ระบบ (POST)
  router.post('/', authController.loginUser);
  
  // เส้นทางการออกจากระบบ
 router.get('/logout', (req, res) => {
    req.session.destroy((err) => {
      if (err) {
        return res.status(500).send("Failed to log out");
      }
      res.redirect('/');
    });
  });
  


// เส้นทางการแสดงข้อมูลสินค้า
router.get('/product', productController.searchProduct);

// เส้นทางการแสดงฟอร์มแก้ไขสินค้า
router.get('/edit/:id', productController.editProductForm);

// เส้นทางการอัปเดตสินค้า (เฉพาะ quantity)
router.post('/update', productController.updateProductQuantity);

// เส้นทางการสร้างสินค้าใหม่
router.post('/create', productController.createProduct);

// เส้นทางการลบสินค้า
router.get('/delete/:id', productController.deleteProduct);

const categoryController = require('../controllers/categoryController');

// Route สำหรับแสดงฟอร์มการสร้างหมวดหมู่สินค้า
router.get('/create-category', categoryController.createCategoryForm);

// Route สำหรับเพิ่มหมวดหมู่สินค้าใหม่
router.post('/create-category', categoryController.createCategory);

// Route สำหรับแสดงรายการหมวดหมู่
router.get('/category-list', categoryController.getCategoryList);

// Route สำหรับการแก้ไขหมวดหมู่
router.get('/edit-category/:id', categoryController.editCategoryForm);
router.post('/edit-category/:id', categoryController.updateCategory);

// Route สำหรับลบหมวดหมู่
router.get('/delete-category/:id', categoryController.deleteCategory);

const supplierController = require('../controllers/supplierController');

// Route สำหรับหน้า Create Supplier
router.get('/create-supplier', supplierController.createSupplierForm);

// Route สำหรับบันทึกข้อมูลผู้จัดจำหน่าย
router.post('/create-supplier', supplierController.createSupplier);
router.get('/supplier-list', supplierController.getSupplierList);

router.get('/edit-supplier/:id', supplierController.editSupplierForm);
router.post('/edit-supplier/:id', supplierController.updateSupplier);
// เส้นทางการลบผู้จัดจำหน่าย
// routes/index.js
// Route สำหรับลบผู้จัดจำหน่าย
router.get('/delete-supplier/:id', (req, res) => {
  const { id } = req.params;

  // คำสั่ง SQL เพื่อทำการลบข้อมูล
  const query = 'DELETE FROM suppliers WHERE id = ?';

  db.execute(query, [id])
    .then(() => {
      res.redirect('/supplier-list');  // เปลี่ยนเส้นทางไปที่ supplier-list หลังการลบ
    })
    .catch((err) => {
      console.error(err);
      res.status(500).send('Error deleting supplier');
    });
});


// routes/index.js
router.post('/delete-supplier/:id', (req, res) => {
  const { id } = req.params;

  // ลบข้อมูลจากฐานข้อมูล
  db.query('DELETE FROM suppliers WHERE id = ?', [id], (err, result) => {
    if (err) {
      console.log(err);
      return res.status(500).send('Error deleting supplier');
    }

    // หลังลบ, เปลี่ยนเส้นทางไปที่ supplier-list
    res.redirect('/supplier-list');
  });
});

const brandController = require('../controllers/brandController');

// Route สำหรับแสดงฟอร์มการสร้างแบรนด์
router.get('/create-brand', brandController.createBrandForm);

// Route สำหรับบันทึกแบรนด์ใหม่
router.post('/create-brand', brandController.createBrand);

// Route สำหรับแสดงรายชื่อแบรนด์ทั้งหมด
router.get('/brand-list', brandController.getBrandList);

// Route สำหรับการแก้ไขแบรนด์
router.get('/edit-brand/:id', brandController.editBrandForm);

// Route สำหรับการอัปเดตแบรนด์
router.post('/edit-brand/:id', brandController.updateBrand);

// Route สำหรับลบแบรนด์
// Route สำหรับลบแบรนด์
router.get('/delete-brand/:id', (req, res) => {
  const { id } = req.params;

  // คำสั่ง SQL เพื่อทำการลบข้อมูลแบรนด์
  const query = 'DELETE FROM brands WHERE id = ?';

  db.execute(query, [id])
    .then(() => {
      res.redirect('/brand-list');  // หลังจากลบ, เปลี่ยนเส้นทางไปที่ brand-list
    })
    .catch((err) => {
      console.error(err);
      res.status(500).send('Error deleting brand');
    });
});


module.exports = router;
